@@ -112,10 +112,10 @@ class EsOp():
         else:
             return '未查到'
 
-    def index_search(self,index_name,body,size=1000):
-        result =  self.conn.search(index=index_name,size=size,body=body)
+    def index_search(self,index_name,body,size=1000,request_timeout=10):
+        result =  self.conn.search(index=index_name,size=size,body=body,request_timeout=request_timeout)
         return self.index_result_dict(result)
-    def index_search_all(self,index_name,pn=1,size=10000,doc_type=''):
+    def index_search_all(self,index_name,pn=1,size=10000,doc_type='',request_timeout=10):
         body = {
             "query": {
                 "match_all": {}
@@ -123,27 +123,27 @@ class EsOp():
             "from": (pn - 1) * size,
             "size": size,
         }
-        result = self.conn.search(index=index_name,doc_type=doc_type, body=body)
+        result = self.conn.search(index=index_name,doc_type=doc_type, body=body,request_timeout=request_timeout)
         return self.index_result_dict(result)
-    def index_search_absolute_match(self,index_name,query_dict,pn=1,size=10,doc_type=''):
+    def index_search_absolute_match(self,index_name,query_dict,pn=1,size=10,doc_type='',request_timeout=10):
         new_dict= {}
         for i in query_dict.keys():
             if i == '_id':
                 new_dict[i] = query_dict[i]
             else:
                 new_dict[i+'.keyword'] =query_dict[i]
-        iterator = Search(using=self.client, doc_type=doc_type, index=index_name).query("term", **new_dict)[(pn - 1) * size:pn*size]
+        iterator = Search(using=self.client, doc_type=doc_type, index=index_name,request_timeout=request_timeout).query("term", **new_dict)[(pn - 1) * size:pn*size]
         iterator = iterator.execute().to_dict()
         return self.index_result_dict(iterator)
 
-    def index_search_fuzzy_match(self,index_name,query_dict,pn=1,size=10,doc_type=''):
-        iterator = Search(using=self.client, doc_type=doc_type,index=index_name).query("match", **query_dict)[(pn - 1) * size:pn*size]
+    def index_search_fuzzy_match(self,index_name,query_dict,pn=1,size=10,doc_type='',request_timeout=10):
+        iterator = Search(using=self.client, doc_type=doc_type,index=index_name,request_timeout=request_timeout).query("match", **query_dict)[(pn - 1) * size:pn*size]
         iterator = iterator.execute().to_dict()
         return self.index_result_dict(iterator)
 
-    def index_MultiMatch(self,index_name,query_text,query_field_list,doc_type=''):
+    def index_MultiMatch(self,index_name,query_text,query_field_list,doc_type='',request_timeout=10):
         multi_match = MultiMatch(query=query_text, fields=query_field_list)
-        iterator= Search(using=self.client,doc_type=doc_type,index=index_name).query(multi_match)
+        iterator= Search(using=self.client,doc_type=doc_type,index=index_name,request_timeout=request_timeout).query(multi_match)
         result = []
         for i in iterator:
             result.append(i.to_dict())
